@@ -86,11 +86,15 @@ func createCommandLine(cmdType string, cmdArgs []string) *exec.Cmd {
 	case system.CleanJobType:
 		return exec.Command("/usr/bin/lastore-apt-clean")
 	case system.BackupJobType:
-		return exec.Command(system.DeepinImmutableCtlPath, "admin", "deploy", "--backup", "-j")
+		return exec.Command(system.DeepinImmutableCtlPath, "admin", "deploy", "--backup", "-j", "-w")
 	case system.IncrementalDownloadJobType:
-		return exec.Command(system.DeepinImmutableCtlPath, "upgrade", "--download-only", "--status-fd", "3")
+		args := []string{"upgrade", "--download-only", "--status-fd", "3"}
+		args = append(args, cmdArgs...)
+		return exec.Command(system.DeepinImmutableCtlPath, args...)
 	case system.IncrementalUpdateJobType:
-		return exec.Command(system.DeepinImmutableCtlPath, "upgrade", "--status-fd", "3")
+		args := []string{"upgrade", "--status-fd", "3"}
+		args = append(args, cmdArgs...)
+		return exec.Command(system.DeepinImmutableCtlPath, args...)
 	case system.FixErrorJobType:
 		var errType system.JobErrorType
 		if len(cmdArgs) >= 1 {
