@@ -8,10 +8,11 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
 	"sync"
 	"time"
 
+	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
+
 	"github.com/linuxdeepin/go-lib/dbusutil"
 )
 
@@ -62,8 +63,20 @@ type Job struct {
 	updateTyp system.UpdateType
 
 	errLogPath []string
+
+	initiator Initiator // source of trigger
 }
 
+// Initiator is the source of trigger
+type Initiator uint
+
+const (
+	// initiatorUser User manually triggered
+	initiatorUser Initiator = iota
+	// initiatorAuto Automatically triggered
+	initiatorAuto
+)
+
 func NewJob(service *dbusutil.Service, id, jobName string, packages []string, jobType, queueName string, environ map[string]string) *Job {
 	j := &Job{
 		service:    service,
@@ -145,11 +158,24 @@ func (j *Job) updateInfo(info system.JobProgressInfo) bool {
 	if info.Status == system.RunningStatus && j.realRunningHookFn != nil {
 		j.realRunningHookFn()
 	}
-	cProgress := buildProgress(info.Progress, j.progressRangeBegin, j.progressRangeEnd)
-	if cProgress > j.Progress {
+
+	var newProgress float64
+	var shouldUpdateProgress bool
+
+	if info.ResetProgress {
+		newProgress = 0
+		shouldUpdateProgress = true
+	} else {
+		newProgress = buildProgress(info.Progress, j.progressRangeBegin, j.progressRangeEnd)
+		// Only update when new progress is greater than current progress
+		shouldUpdateProgress = newProgress > j.Progress
+	}
+
+	if shouldUpdateProgress {
+		// Update progress
 		changed = true
-		j.Progress = cProgress
-		_ = j.emitPropChangedProgress(cProgress)
+		j.Progress = newProgress
+		_ = j.emitPropChangedProgress(newProgress)
 	}
 
 	// see the apt.go, we scale download progress value range in [0,0.5
@@ -319,3 +345,10 @@ func (j *Job) subRetryCount(toZero bool) {
 	}
 	j.retry--
 }
+
+// HasStatus check if the job has the given status
+func (j *Job) HasStatus(status system.Status) bool {
+	j.PropsMu.RLock()
+	defer j.PropsMu.RUnlock()
+	return j.Status == status
+}
