@@ -150,7 +150,10 @@ func (m *Manager) updateSource(sender dbus.Sender) (*Job, error) {
 				go func() {
 					m.inhibitAutoQuitCountAdd()
 					defer m.inhibitAutoQuitCountSub()
-					m.updatePlatform.PostStatusMessage("update source success")
+					m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+						Type:   "info",
+						Detail: "update source success",
+					})
 				}()
 				m.updatePlatform.SaveCache(m.config)
 				job.setPropProgress(1.0)
@@ -177,7 +180,12 @@ func (m *Manager) updateSource(sender dbus.Sender) (*Job, error) {
 					m.inhibitAutoQuitCountAdd()
 					defer m.inhibitAutoQuitCountSub()
 					m.reportLog(updateStatusReport, false, job.Description)
-					m.updatePlatform.PostStatusMessage(fmt.Sprintf("apt-get update failed, detail is %v , option is %+v", job.Description, job.option))
+
+					m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+						Type:           "error",
+						JobDescription: job.Description,
+						Detail:         fmt.Sprintf("apt-get update failed, detail is %v , option is %+v", job.Description, job.option),
+					})
 				}()
 				return nil
 			},
@@ -472,7 +480,10 @@ func (m *Manager) refreshUpdateInfos(sync bool) {
 			go func() {
 				m.inhibitAutoQuitCountAdd()
 				defer m.inhibitAutoQuitCountSub()
-				m.updatePlatform.PostStatusMessage(fmt.Sprintf("generate package list error, detail is %v:", e))
+				m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+					Type:   "error",
+					Detail: fmt.Sprintf("generate package list error, detail is %v:", e),
+				})
 			}()
 			logger.Warning(e)
 		}
@@ -488,7 +499,12 @@ func (m *Manager) refreshUpdateInfos(sync bool) {
 					go func() {
 						m.inhibitAutoQuitCountAdd()
 						defer m.inhibitAutoQuitCountSub()
-						m.updatePlatform.PostStatusMessage(fmt.Sprintf("generate package list error, detail is %v:", e))
+
+						m.updatePlatform.PostStatusMessage(updateplatform.StatusMessage{
+							Type:   "error",
+							Detail: fmt.Sprintf("generate package list error, detail is %v:", e),
+						})
+
 					}()
 					logger.Warning(e)
 				}
@@ -503,7 +519,7 @@ func (m *Manager) refreshUpdateInfos(sync bool) {
 		go func() {
 			m.inhibitAutoQuitCountAdd()
 			logger.Info("auto download force updates")
-			_, err := m.prepareDistUpgrade(dbus.Sender(m.service.Conn().Names()[0]), system.SystemUpdate) // TODO system.SystemUpdate
+			_, err := m.prepareDistUpgrade(dbus.Sender(m.service.Conn().Names()[0]), system.SystemUpdate, initiatorAuto) // TODO system.SystemUpdate
 			if err != nil {
 				logger.Error("failed to prepare dist-upgrade:", err)
 			}
@@ -527,7 +543,7 @@ func (m *Manager) refreshUpdateInfos(sync bool) {
 		logger.Info("auto download updates")
 		go func() {
 			m.inhibitAutoQuitCountAdd()
-			_, err := m.prepareDistUpgrade(dbus.Sender(m.service.Conn().Names()[0]), m.CheckUpdateMode)
+			_, err := m.prepareDistUpgrade(dbus.Sender(m.service.Conn().Names()[0]), m.CheckUpdateMode, initiatorAuto)
 			if err != nil {
 				logger.Error("failed to prepare dist-upgrade:", err)
 			}
