@@ -9,8 +9,6 @@ import (
 	"bytes"
 	"errors"
 	"fmt"
-	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
-	"github.com/linuxdeepin/lastore-daemon/src/internal/system/apt"
 	"io"
 	"os"
 	"os/exec"
@@ -18,6 +16,9 @@ import (
 	"strings"
 	"syscall"
 	"time"
+
+	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
+	"github.com/linuxdeepin/lastore-daemon/src/internal/system/apt"
 )
 
 func buildUpgradeInfoRegex(archs []system.Architecture) *regexp.Regexp {
@@ -109,6 +110,7 @@ func queryDpkgUpgradeInfoByAptList(sourcePath string) ([]string, error) {
 	}
 	args = append(args, []string{"list", "--upgradable"}...)
 	cmd := exec.Command("apt", append(args, ps...)...) // #nosec G204
+	cmd.Env = append(os.Environ(), "IMMUTABLE_DISABLE_REMOUNT=true")
 	r, err := cmd.StdoutPipe()
 	if err != nil {
 		return nil, err
@@ -142,7 +144,9 @@ func queryDpkgUpgradeInfoByAptList(sourcePath string) ([]string, error) {
 }
 
 func getSystemArchitectures() []system.Architecture {
-	foreignArchs, err := exec.Command("dpkg", "--print-foreign-architectures").Output()
+	cmd := exec.Command("dpkg", "--print-foreign-architectures")
+	cmd.Env = append(os.Environ(), "IMMUTABLE_DISABLE_REMOUNT=true")
+	foreignArchs, err := cmd.Output()
 	if err != nil {
 		logger.Warningf("GetSystemArchitecture failed:%v\n", foreignArchs)
 	}
